@@ -17,8 +17,8 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
         },
 
         # MATERIAL THEME
-        baseColor   => undef,
         accentColor => undef,
+        baseColor   => undef,
         darkMode    => \0,
 
         defaultMask => {
@@ -52,9 +52,9 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
 
             // set material theme
             me.setTheme(localStorage.theme != null ? JSON.parse(localStorage.theme) : {
-                darkMode: me.darkMode,
+                accent: me.accentColor,
                 base: me.baseColor,
-                accent: me.accentColor
+                darkMode: me.darkMode
             });
 
             Ext.util.History.hashbang = true;
